<?php	
namespace Amedea\Widgets;

use \Elementor\Widget_Base;
use \Elementor\Controls_Manager;

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */

class amedea__halloween extends Widget_Base {

	/**
	* Retrieve the widget name.
	*
	* @since 1.0.0
	*
	* @return string Widget name.
	*/

	public function get_name() {
		return 'holiday_season_halloween';
	}
	
	/**
	* Retrieve the widget title.
	*
	* @since 1.0.0
	*
	* @return string Widget title.
	*/

	public function get_title() {
		return esc_html__( 'Halloween Season', 'amedea' );
	}
	
	/**
	* Retrieve the widget icon.
	*
	* @since 1.0.0
	*
	* @return string Widget icon.
	*/

	public function get_icon() {
		return 'eicon-nerd-chuckle';
	}

	/**
	* Retrieve the list of scripts the widget depended on.
	*
	* Used to set scripts dependencies required to run the widget.
	*
	* @since 1.0.0
	*
	* @return array Widget scripts dependencies.
	*/

	public function get_script_depends() {
		return [ 'countdown' , 'parallax' , 'amedea-holiday-season' ];
	}

	/**
	 * Retrieve the list of style the widget depended on.
	 *
	 * Used to set styles dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget style dependencies.
	 */
	 
	public function get_style_depends() {
		return [ 'holiday-season' ];
	}
	
	/**
	* Retrieve the list of categories the widget belongs to.
	*
	* Used to determine where to display the widget in the editor.
	*
	* Note that currently Elementor supports only one category.
	* When multiple categories passed, Elementor uses the first one.
	*
	* @since 1.0.0
	*
	* @return array Widget categories.
	*/

	public function get_categories() {
		return [ 'amedea-category' , 'amedea-holiday-season-category' ];
	}


	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function register_controls() {

		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Configuration', 'amedea' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'title',
			[
				'label' => esc_html__( 'Title', 'amedea' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'Zombies everywhere!', 'amedea' ),
				'placeholder' => esc_html__( 'Type your content here', 'amedea' ),
			]
		);
		
		$this->add_control(
			'subtitle',
			[
				'label' => esc_html__( 'Subtitle', 'amedea' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'There is noone but the zombies here at the moment. We will come back really soon!', 'amedea' ),
				'placeholder' => esc_html__( 'Type your content here', 'amedea' ),
			]
		);
		
		$this->add_control(
			'datevisibility',
			array(
			  'label'       => esc_html__('Show Countdown', 'fullscreen-menu'),
			  'type'        => \Elementor\Controls_Manager::SELECT,
			  'default'     => 'visible',
			  'label_block' => true,
			  'options' => array(
				'visible' => esc_html__('Visible', 'fullscreen-menu'),
				'hidden' => esc_html__('Hidden', 'fullscreen-menu'),
			  )
			)
		  );
		
		$this->add_control(
			'date',
			[
				'label' => esc_html__( 'Date', 'amedea' ),
				'type' => \Elementor\Controls_Manager::DATE_TIME,
			]
		);
				
		$this->end_controls_section();

	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings	= $this->get_settings_for_display();		
	?>
	<!-- Halloween pack is brought by https://Amedea.Pro - Get your own copy now for free!! -->
	<section class="holiday--season hs--halloween">
		<div class="holiday--season-container">
			<h1><?php echo esc_html($settings['title']); ?></h1>
			<p><?php echo esc_html($settings['subtitle']); ?></p>
			<div id="defaultCountdown" class="<?php echo esc_html($settings['datevisibility']); ?>"></div>
		</div>
		<div class="parallax-viewport" id="parallax">
			<div class="parallax-layer layer1">
				<img src="<?php echo str_replace("widgets/holiday-season/","",plugin_dir_url( __FILE__ )).'assets/images/ground.png' ?>" alt="" />
			</div>
			<div class="parallax-layer layer2">
				<img src="<?php echo str_replace("widgets/holiday-season/","",plugin_dir_url( __FILE__ )).'assets/images/children2.png' ?>" alt="" class="image2" />
			</div>
			<div class="parallax-layer layer3">
				<img src="<?php echo str_replace("widgets/holiday-season/","",plugin_dir_url( __FILE__ )).'assets/images/children1.png' ?>" alt="" class="image3" />
			</div>
			<div class="parallax-layer layer4">
				<img src="<?php echo str_replace("widgets/holiday-season/","",plugin_dir_url( __FILE__ )).'assets/images/children3.png' ?>" alt="" class="image4" />
			</div>
			<div class="parallax-layer layer5">
				<img src="<?php echo str_replace("widgets/holiday-season/","",plugin_dir_url( __FILE__ )).'assets/images/children4.png' ?>" alt="" class="image5" />
			</div>
		</div>
	</section>
	<script type="text/javascript">
        <?php $launch_date  = esc_html($settings['date']); ?>/* <![CDATA[ */var JSParams = {"launch_date": "<?php echo $launch_date; ?>","admin_ajax_url": "<?php echo home_url()  . '/wp-admin/admin-ajax.php'; ?>"};/* ]]> */
	</script>
	<!-- Halloween pack is brought by https://Amedea.Pro - Get your own copy now for free!! -->
	<?php
	
	}

	/**
	* Render the widget output in the editor.
	*
	* Written as a Backbone JavaScript template and used to generate the live preview.
	*
	* @since 1.0.0
	*/

	protected function content_template() {}
}